@@ -1,4 +1,5 @@
 package Filter::Decompress ;
+# For usage see examples/filtdef
  
 use Filter::Util::Call ;
 use Compress::Zlib ;
@@ -7,20 +8,19 @@ use Carp ;
 use strict ;
 use warnings ;
 
-our $VERSION = '1.01' ;
+our $VERSION = '1.02' ;
 
 sub import
 {
     my ($self) = @_ ;
 
     # Initialise an inflation stream.
-    my $x = inflateInit() 
-        or croak "Internal Error" ;
+    my $x = inflateInit()
+        or croak "Internal Error inflateInit" ;
     filter_add(
         sub 
         { 
             my ($status, $err) ;
-        
             if (($status = filter_read()) >0) {
                 ($_, $err) = $x->inflate($_) ;
                 return -1 unless $err == Z_OK or $err == Z_STREAM_END ;
